@@ -15,17 +15,17 @@ class TForm2 : public TForm
 __published:	// IDE-managed Components
 	TPanel *Panel1;
 	TPanel *Panel2;
-	TCheckBox *CheckBox1;
-	TCheckBox *CheckBox2;
-	TButton *Button1;
 	TListBox *ListBox1;
 	TPanel *Panel3;
 	TMemo *SearchText;
 	TPanel *plPreview;
+	TRadioGroup *searchTypeGroup;
+	TGroupBox *GroupBox1;
+	TCheckBox *CheckBox2;
+	TPanel *Panel4;
+	TButton *Button1;
 	void __fastcall Button1Click(TObject *Sender);
 	void __fastcall ListBox1DblClick(TObject *Sender);
-	void __fastcall CheckBox1Click(TObject *Sender);
-	
 	void __fastcall ListBox1Click(TObject *Sender);
 private:	// User declarations
 	SWDispRTF *pvrtf;
