@@ -7,7 +7,7 @@
 #include <swconfig.h>
 #include <swlog.h>
 
-using namespace std;
+// using namespace std;
 
 typedef map <string, SWModule *, less<string> > ModMap;
 
@@ -29,7 +29,7 @@ public:
 	ModMap Modules;
 
 	SWMgr(SWConfig *iconfig = 0, bool autoload = true);
-	~SWMgr();
+	virtual ~SWMgr();
 	void InstallScan(const char *dir);
 	void Load();
 };
