@@ -42,7 +42,7 @@ public:
 	virtual char *Name(char *imodname = 0);
 	virtual char *Description(char *imoddesc = 0);
 	virtual char *Type(char *imodtype = 0);
-	virtual SWListKey &Search(const char *istr, int flags = 0);
+	virtual SWListKey &Search(const char *istr, int searchType = 0, int flags = 0);
 
 	virtual SWKey *CreateKey();
 
